USB_SERIAL

Struct USB_SERIAL 

pub struct USB_SERIAL<'a>(/* private fields */);

Implementations

Source

impl USB_SERIAL<'_>

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub unsafe fn reborrow(&mut self) -> USB_SERIAL<'_>

Creates a new peripheral reference with a shorter lifetime.

Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.

Safety

You must ensure that you are not using reborrowed peripherals in drivers which are forgotten via core::mem::forget.